@@ -37,12 +37,12 @@ def enum_next(e: E) -> E:
     ...     summer = 3
     ...     autumn = 4
 
-    >>> enum_next(Seasons.winter)
-    <Seasons.spring: 2>
-    >>> enum_next(Seasons.spring)
-    <Seasons.summer: 3>
-    >>> enum_next(Seasons.autumn)
-    <Seasons.winter: 1>
+    >>> enum_next(Seasons.winter).name
+    'spring'
+    >>> enum_next(Seasons.spring).name
+    'summer'
+    >>> enum_next(Seasons.autumn).name
+    'winter'
     """
     return e.__class__((e.value % max(e.__class__)) + 1)
 
@@ -253,7 +253,7 @@ class UI:
     duration_mode: DurationMode = attr.ib(
         default=DurationMode.query, converter=DurationMode
     )
-    verbose_mode: QueryDisplayMode = attr.ib(
+    query_display_mode: QueryDisplayMode = attr.ib(
         default=QueryDisplayMode.default(), converter=QueryDisplayMode
     )
     sort_key: SortKey = attr.ib(default=SortKey.default(), converter=SortKey)
@@ -372,10 +372,11 @@ class UI:
         if Flag.WAIT & flag:
             add_column(
                 key="wait",
-                name="W",
-                template_h="%2s ",
-                transform=utils.yn,
+                name="Waiting",
+                template_h="%16s ",
+                transform=utils.wait_status,
                 color_key=colors.wait,
+                max_width=16,
             )
         if Flag.WRITE & flag:
             add_column(
@@ -426,6 +427,7 @@ class UI:
                 "type",
                 "mode",
                 "duration",
+                "wait",
                 "state",
                 "query",
             ],
@@ -526,7 +528,7 @@ class UI:
             return
         forbidden = set(changes) - {
             "duration_mode",
-            "verbose_mode",
+            "query_display_mode",
             "sort_key",
             "query_mode",
             "refresh_time",
@@ -543,8 +545,8 @@ class UI:
         """Return the column matching 'key'.
 
         >>> ui = UI.make()
-        >>> ui.column("cpu")
-        Column(name='CPU%', template_h='%6s ', mandatory=False, sort_key=<SortKey.cpu: 1>)
+        >>> ui.column("cpu")  # doctest: +ELLIPSIS
+        Column(name='CPU%', template_h='%6s ', mandatory=False, sort_key=...)
         >>> ui.column("gloups")
         Traceback (most recent call last):
           ...
@@ -696,13 +698,13 @@ class BaseProcess:
 class RunningProcess(BaseProcess):
     """Process for a running query."""
 
-    wait: bool
+    wait: Union[bool, None, str]
     is_parallel_worker: bool
 
 
 @attr.s(auto_attribs=True, frozen=True, slots=True)
-class BWProcess(BaseProcess):
-    """Process for a blocking or waiting query."""
+class WaitingProcess(BaseProcess):
+    """Process for a waiting query."""
 
     # Lock information from pg_locks view
     # https://www.postgresql.org/docs/current/view-pg-locks.html
@@ -714,6 +716,21 @@ class BWProcess(BaseProcess):
     is_parallel_worker: bool = attr.ib(default=False, init=False)
 
 
+@attr.s(auto_attribs=True, frozen=True, slots=True)
+class BlockingProcess(BaseProcess):
+    """Process for a blocking query."""
+
+    # Lock information from pg_locks view
+    # https://www.postgresql.org/docs/current/view-pg-locks.html
+    mode: str
+    type: LockType = attr.ib(converter=locktype)
+    relation: str
+    wait: Union[bool, None, str]
+
+    # TODO: update queries to select/compute this column.
+    is_parallel_worker: bool = attr.ib(default=False, init=False)
+
+
 @attr.s(auto_attribs=True, frozen=True, slots=True)
 class SystemProcess:
     meminfo: Tuple[int, ...]
@@ -866,8 +883,9 @@ class SelectableProcesses:
 
 
 ActivityStats = Union[
-    Iterable[BWProcess],
+    Iterable[WaitingProcess],
     Iterable[RunningProcess],
-    Tuple[Iterable[BWProcess], SystemInfo],
+    Tuple[Iterable[WaitingProcess], SystemInfo],
+    Tuple[Iterable[BlockingProcess], SystemInfo],
     Tuple[Iterable[LocalRunningProcess], SystemInfo],
 ]
